<?php

namespace App\domain\travelport;

use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;


class FlightOfferService extends SearchOfferAPI
{
    protected array $passengerCriteria;
    protected array $searchCriteriaFlight;

    public function requestOffers(array $passengerCriteria, array $searchCriteriaFlight, ?array $searchModifiers, string $source)
    {
        try {
            $apiUrl = $this->buildApiUrl();

            $payload = $this->createPayload($passengerCriteria, $searchCriteriaFlight, $searchModifiers, $source);

//            Log::info("#payload: ", $payload);

            $response = $this->client->post($apiUrl, [
                'headers' => $this->getHeaders(),
                'json' => $payload,
            ]);

            return json_decode($response->getBody(), true);
        } catch (Exception $e) {
            Log::error('Error requestOffers: ' . $e->getMessage());
            return null;
        } catch (GuzzleException $e) {
            Log::error('Error Guzzle: ' . $e->getMessage());
            return null;
        }
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/catalog/search/catalogproductofferings";
    }

    protected function createPayload(array $passengerCriteria, array $searchCriteriaFlight, ?array $searchModifiers, string $source): array
    {
        return [
            "CatalogProductOfferingsQueryRequest" => [
                "CatalogProductOfferingsRequest" => [
                    "@type" => "CatalogProductOfferingsRequestAir",
                    "offersPerPage" => 10,
                    "maxNumberOfUpsellsToReturn" => 0,
                    "inhibitBrandContentInd" => true,
                    "contentSourceList" => [
                        $source
                    ],
                    "PassengerCriteria" => $passengerCriteria,
                    "SearchCriteriaFlight" => $searchCriteriaFlight,
                    "SearchModifiersAir" => [
                        "@type" => "SearchModifiersAir",
//                        "CarrierPreference" => [
//                            [
//                                "@type" => "CarrierPreference",
//                                "preferenceType" => "Permitted",
//                                "carriers" => [
//                                    "AA"
//                                ]
//                            ]
//                        ],
                        "CabinPreference" => $searchModifiers["cabinPreference"],
                        "ConnectionPreferences" => [
                            [
                                "@type" => "ConnectionPreferencesAir",
                                "FlightType" => [
                                    "@type" => "FlightType",
                                    "connectionType" =>
                                        $searchModifiers['flightType']
                                            ? $searchModifiers['flightType']['connectionType']
                                            : null,
                                    "excludeInterlineConnectionsInd" => true
                                ]
                            ],
//                            [
//                                "@type" => "ConnectionPreferences",
//                                "maxConnectionDuration" => "PT6H",
//                                "maxOvernightDuration" => "PT6H"
//                            ]
                        ]
                    ]
                ]
            ]
        ];
    }
}
